@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview: an image viewer
-Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2008 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -51,7 +51,6 @@ public:
 	~ThumbnailViewPanel();
 
 	void applyPalette(const QPalette&);
-	void initActionDependentWidgets();
 
 	ThumbnailView* thumbnailView() const;
 	KUrlNavigator* urlNavigator() const;
@@ -68,6 +67,7 @@ private Q_SLOTS:
 	void slotDirModelReset();
 	void updateSortOrder();
 	void updateThumbnailDetails();
+	void updateSliderToolTip(int sliderAction);
 
 private:
 	ThumbnailViewPanelPrivate* const d;
