@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview: an image viewer
-Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2008 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -39,10 +39,14 @@ class HudWidgetPrivate;
 class GWENVIEWLIB_EXPORT HudWidget : public QFrame {
 	Q_OBJECT
 public:
-	enum Options {
-		OptionNone,
-		OptionCloseButton
+	enum Option {
+		OptionNone                 = 0,
+		OptionCloseButton          = 1 << 1,
+		// FIXME: Ugly
+		OptionDoNotFollowChildSize = 1 << 2, /// Make it possible to resize the hudwidget independently of child size
+		OptionOpaque               = 1 << 3
 	};
+	Q_DECLARE_FLAGS(Options, Option)
 
 	HudWidget(QWidget* parent = 0);
 	~HudWidget();
@@ -51,7 +55,11 @@ public:
 
 	QWidget* mainWidget() const;
 
-	QToolButton* closeButton() const;
+Q_SIGNALS:
+	void closed();
+
+private Q_SLOTS:
+	void slotCloseButtonClicked();
 
 private:
 	HudWidgetPrivate* const d;
@@ -60,4 +68,6 @@ private:
 
 } // namespace
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Gwenview::HudWidget::Options)
+
 #endif /* HUDWIDGET_H */
