@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview: an image viewer
-Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2008 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -57,8 +57,7 @@ public:
 	};
 	// FIXME: Find out why this cause problems with Qt::Alignment in
 	// PreviewItemDelegate!
-	//Q_DECLARE_FLAGS(ThumbnailDetails, ThumbnailDetail);
-	typedef int ThumbnailDetails;
+	Q_DECLARE_FLAGS(ThumbnailDetails, ThumbnailDetail)
 
 	/**
 	 * Returns which thumbnail details are shown
@@ -85,6 +84,7 @@ private Q_SLOTS:
 	void slotRotateRightClicked();
 	void slotFullScreenClicked();
 	void slotToggleSelectionClicked();
+	void slotRowsChanged();
 
 protected:
 	virtual bool eventFilter(QObject*, QEvent*);
@@ -94,10 +94,10 @@ private:
 	friend class PreviewItemDelegatePrivate;
 };
 
-// See upper
-//Q_DECLARE_OPERATORS_FOR_FLAGS(Gwenview::ThumbnailView::ThumbnailDetails)
-
 
 } // namespace
 
+// See upper
+Q_DECLARE_OPERATORS_FOR_FLAGS(Gwenview::PreviewItemDelegate::ThumbnailDetails)
+
 #endif /* PREVIEWITEMDELEGATE_H */
